import { Template } from "../../store/useTemplateStore";
import { captureVisualization } from "./captureVisualization";

type HandleSaveTemplateProps = {
  addTemplate: (template: Template) => void;
  selectedZone: {
    panelOrder: string[]; // Adjust the type based on actual data structure
    widgets: any[]; // Replace `any` with the actual widget type
  };
  templates?: Template[];
};

// Generate a unique ID (placeholder function)
const generateUniqueId = (): string => {
  return `${Date.now()}-${Math.random().toString(36).substring(2, 15)}`;
};

// Refactored function
export const handleSaveTemplate = async ({
  addTemplate,
  selectedZone,
  templates = [],
}: HandleSaveTemplateProps): Promise<void> => {
  try {
    // Check if the selected zone has any widgets
    if (!selectedZone.widgets || selectedZone.widgets.length === 0) {
      console.warn("Cannot save an empty template.");
      return;
    }

    // Check if the template already exists
    const isDuplicate = templates.some((template) => {
      const isSamePanelOrder =
        JSON.stringify(template.panelOrder) ===
        JSON.stringify(selectedZone.panelOrder);
      const isSameWidgets =
        JSON.stringify(template.widgets) ===
        JSON.stringify(selectedZone.widgets);
      return isSamePanelOrder && isSameWidgets;
    });

    if (isDuplicate) {
      console.warn("This template already exists.");
      return;
    }

    // Capture visualization snapshot
    const snapshot = await captureVisualization();
    if (!snapshot) {
      console.error("Failed to capture visualization snapshot.");
      return;
    }

    // Create a new template
    const newTemplate: Template = {
      id: generateUniqueId(),
      name: `Template ${Date.now()}`,
      panelOrder: selectedZone.panelOrder,
      widgets: selectedZone.widgets,
      snapshot,
    };

    console.log("Saving template:", newTemplate);

    // Save the template
    try {
      addTemplate(newTemplate);
    } catch (error) {
      console.error("Failed to add template:", error);
    }
  } catch (error) {
    console.error("Failed to save template:", error);
  }
};
